==> h2o-java-rest-bindings-3.8.2.2-sources.jar: water/bindings/pojos/DeepLearningV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;
public class DeepLearningV3 extends ModelBuilderSchema {
    /* INHERITED: Model builder parameters. 
     * public DeepLearningParametersV3 parameters;
     */

    /* INHERITED: The algo name for this ModelBuilder. 
     * public String algo;
     */

    /* INHERITED: The pretty algo name for this ModelBuilder (e.g., Generalized Linear Model, rather than GLM). 
     * public String algo_full_name;
     */

    /* INHERITED: Model categories this ModelBuilder can build. 
     * public ModelCategory[] can_build;
     */

    /* INHERITED: Should the builder always be visible, be marked as beta, or only visible if the user starts up with the experimental flag? 
     * public BuilderVisibility visibility;
     */

    /* INHERITED: Job Key 
     * public JobV3 job;
     */

    /* INHERITED: Parameter validation messages 
     * public ValidationMessageV3[] messages;
     */

    /* INHERITED: Count of parameter validation errors 
     * public int error_count;
     */

    /* INHERITED: HTTP status to return for this build. 
     * public int __http_status;
     */

    /* INHERITED: Comma-separated list of JSON field paths to exclude from the result, used like: "/3/Frames?_exclude_fields=frames/frame_id/URL,__meta" 
     * public String _exclude_fields;
     */

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}

==> h2o-java-rest-bindings-3.8.2.6-sources.jar: water/bindings/pojos/DeepLearningV3.java <==
package water.bindings.pojos;

import com.google.gson.Gson;

public class DeepLearningV3 extends ModelBuilderSchema {
    /* INHERITED: Model builder parameters. 
    public ModelParameterSchemaV3[] parameters;
     */
    /* INHERITED: The algo name for this ModelBuilder. 
    public String algo = "";
     */

    /* INHERITED: The pretty algo name for this ModelBuilder (e.g., Generalized Linear Model, rather than GLM). 
    public String algo_full_name = "";
     */

    /* INHERITED: Model categories this ModelBuilder can build. 
    public ModelCategory[] can_build = null;
     */

    /* INHERITED: Should the builder always be visible, be marked as beta, or only visible if the user starts up with the experimental flag? 
    public ModelBuilderBuilderVisibility visibility = null;
     */

    /* INHERITED: Job Key 
    public JobV3 job = null;
     */

    /* INHERITED: Parameter validation messages 
    public ValidationMessageV3[] messages = null;
     */

    /* INHERITED: Count of parameter validation errors 
    public int error_count = 0;
     */

    /* INHERITED: HTTP status to return for this build. 
    public int __http_status = 0;
     */

    /* INHERITED: Comma-separated list of JSON field paths to exclude from the result, used like: "/3/Frames?_exclude_fields=frames/frame_id/URL,__meta" 
    public String _exclude_fields = "";
     */

    public DeepLearningV3() {
        algo = "";
        algo_full_name = "";
        can_build = null;
        visibility = null;
        job = null;
        messages = null;
        error_count = 0;
        __http_status = 0;
        _exclude_fields = "";
    }

    /** Return the contents of this object as a JSON String. */
    @Override
    public String toString() {
        return new Gson().toJson(this);
    }
}
